@@ -5,9 +5,11 @@ import Data.GI.CodeGen.CabalHooks (setupBinding, TaggedOverride(..))
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "GLib"
         version = "2.0"
+        pkgName = "gi-glib"
+        pkgVersion = "2.0.26"
         overridesFile = Just "GLib.overrides"
         verbose = False
         outputDir = Nothing
